==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/TimeAxisBreakDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TimeAxisBreakDescription } from "./TimeAxisBreakDescription";
/**
 * @hidden
 */
var TimeAxisBreakDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TimeAxisBreakDescriptionMetadata, _super);
    function TimeAxisBreakDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TimeAxisBreakDescriptionMetadata.b = function (a) {
        if (TimeAxisBreakDescriptionMetadata.a == null) {
            TimeAxisBreakDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TimeAxisBreakDescriptionMetadata.c(TimeAxisBreakDescriptionMetadata.a);
        }
        if (a.g(TimeAxisBreakDescriptionMetadata.a)) {
            return;
        }
        a.s(TimeAxisBreakDescriptionMetadata.a);
    };
    TimeAxisBreakDescriptionMetadata.c = function (a) {
        a.item("Start", "Date");
        a.item("End", "Date");
        a.item("Interval", "TimeSpan");
    };
    TimeAxisBreakDescriptionMetadata.d = function (a) {
        TimeAxisBreakDescriptionMetadata.b(a);
        a.u("TimeAxisBreak", function () { return new TimeAxisBreakDescription(); });
        a.t("TimeAxisBreak", TimeAxisBreakDescriptionMetadata.a);
    };
    TimeAxisBreakDescriptionMetadata.$t = markType(TimeAxisBreakDescriptionMetadata, 'TimeAxisBreakDescriptionMetadata');
    TimeAxisBreakDescriptionMetadata.a = null;
    return TimeAxisBreakDescriptionMetadata;
}(Base));
export { TimeAxisBreakDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/TimeAxisBreakDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TimeAxisBreakDescription } from "./TimeAxisBreakDescription";
/**
 * @hidden
 */
var TimeAxisBreakDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TimeAxisBreakDescriptionMetadata, _super);
    function TimeAxisBreakDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TimeAxisBreakDescriptionMetadata.b = function (a) {
        if (TimeAxisBreakDescriptionMetadata.a == null) {
            TimeAxisBreakDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TimeAxisBreakDescriptionMetadata.c(TimeAxisBreakDescriptionMetadata.a);
        }
        if (a.j(TimeAxisBreakDescriptionMetadata.a)) {
            return;
        }
        a.y(TimeAxisBreakDescriptionMetadata.a);
    };
    TimeAxisBreakDescriptionMetadata.c = function (a) {
        a.item("Start", "Date");
        a.item("End", "Date");
        a.item("Interval", "TimeSpan");
    };
    TimeAxisBreakDescriptionMetadata.d = function (a) {
        TimeAxisBreakDescriptionMetadata.b(a);
        a.aa("TimeAxisBreak", function () { return new TimeAxisBreakDescription(); });
        a.z("TimeAxisBreak", TimeAxisBreakDescriptionMetadata.a);
    };
    TimeAxisBreakDescriptionMetadata.$t = markType(TimeAxisBreakDescriptionMetadata, 'TimeAxisBreakDescriptionMetadata');
    TimeAxisBreakDescriptionMetadata.a = null;
    return TimeAxisBreakDescriptionMetadata;
}(Base));
export { TimeAxisBreakDescriptionMetadata };
